@@ -1,5 +1,4 @@
-from .stern import stern
-
+import stern
 __author__ = 'saivan'
-__version__ = '1.1'
+__version__ = '1.2'
 __email__ = 'vasilsalkou@gmail.com'
\ No newline at end of file
